AtClientPreference class

Class to hold attributes for client preferences. Set the preferences for your application and pass it to AtClientManager.setCurrentAtSign.

Constructors

AtClientPreference()

Properties

atClientParticulars ↔ AtClientParticulars
getter/setter pair
atProtocolEmitted ↔ Version
Poorly named variable which used to control some aspects of at_client's default data encryption. Is now fully ignored.
getter/setter pair
commitLogPath String?
Local device path of commit log
getter/setter pair
cramSecret String?
Shared secret of the atSign
getter/setter pair
crypto CryptoConfig
Configures the crypto provider used for encrypted puts and reads.
getter/setter pair
decryptPackets bool
OptionalParameter when set to true logs TLS Keys to file.
getter/setter pair
downloadPath String?
Default path to download stream files
getter/setter pair
enforceNamespace bool
AtClient.put uses this parameter to decide whether to check for presence of a namespace in the string representation of the AtKey.
getter/setter pair
expiryCheckTimeInterval Duration
Time interval for the scheduled task that removes expired keys from local keyStore
getter/setter pair
fetchOfflineNotifications bool
Fetch the notifications received when the client is offline. Defaults to true. Set to false to ignore the notifications received when device is offline.
getter/setter pair
fileEncryptionChunkSize int
Default chunk size for file encryption and decryption
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hashingAlgoType ↔ HashingAlgoType
hashing algorithm to use for pkam authentication
getter/setter pair
hiveStoragePath String?
Local device path of hive storage
getter/setter pair
isLocalStoreRequired bool
getter/setter pair
keyStoreSecret List<int>?
Secret key to encrypt keystore data
getter/setter pair
maxDataSize int
The maximum size of the value that a secondary server can store. BufferOverFlowException is thrown when size of the value exceeds the maxDataSize
getter/setter pair
monitorAutoStart bool
  • when true, then the notifications monitor will be started either the first time that NotificationService.subscribe is called by the application code, or 30 seconds after creation of the NotificationService if there have been no subscriptions.
  • when false, then the notifications monitor will not be started until explicitly requested to do so by the application calling NotificationService.startListening
  • getter/setter pair
    monitorHeartbeatInterval Duration
    The NotificationService maintains a connection which monitors for new notifications being delivered from the atServer. Because network weather is real, and because it is generally essential for client programs to receive notifications consistently, a heartbeat no-op command is sent to the atServer periodically, at this interval
    getter/setter pair
    monitorHeartbeatResponseTimeout Duration
    When a heartbeat is sent by the notifications monitor, we wait for this length of time to receive a response. If no response is received, then the connection is closed, and the notifications monitor will reconnect.
    getter/setter pair
    namespace String?
    Specifies the namespace of an app.
    getter/setter pair
    networkTimeout Duration?
    The process-wide default network timeout: the maximum wall-clock the SDK will spend reaching/using the atServer (connect + retries + waiting for a response) before giving up. When set on the AtClientPreference used to create an AtClient, it becomes AtNetworkTimeouts.defaultTimeout for the whole process (capped at AtNetworkTimeouts.maxAllowed, 60s). When null, the existing default (30s) applies. This supersedes the misleadingly-named outboundConnectionTimeout, which is a socket idle time, not an operation/connect timeout, and does not bound onboarding/auth.
    getter/setter pair
    outboundConnectionTimeout int
    Idle time in milliseconds of connection to secondary server. Default to 10 minutes.
    getter/setter pair
    pathToCerts String?
    OptionalParameter path to trusted certificates. Required to create security context.
    getter/setter pair
    privateKey String?
    Private key of the atSign
    getter/setter pair
    remoteLocalPref RemoteLocalPref
    Set this to RemoteLocalPref.remoteOnly if you require all data operations (get / put / delete) to be performed on the remote atServer rather than on local storage. (When operations are performed locally, we depend on sync to get eventual consistency between local and remote.
    getter/setter pair
    rootDomain String
    Domain of the root server. Defaults to root.atsign.org
    getter/setter pair
    rootPort int
    Port of the root server. Defaults to 64
    getter/setter pair
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited
    signingAlgoType ↔ SigningAlgoType
    signing algorithm to use for pkam authentication
    getter/setter pair
    syncBatchSize int
    Number of keys to batch for sync to secondary server
    getter/setter pair
    syncIntervalMins int
    Frequency of sync task to run in minutes. Defaults to 10 minutes.
    getter/setter pair
    syncPageLimit int
    The number of keys to pull from cloud secondary to local secondary in a single call.
    getter/setter pair
    syncRegex String?
    regex to perform sync
    getter/setter pair
    syncStrategy SyncStrategy?
    Syncing strategy of the client SyncStrategy Deprecated Use SyncService
    getter/setter pair
    tlsKeysSavePath String?
    OptionalParameter location where the TLS keys will be saved when decryptPackets is set to true
    getter/setter pair
    useAtChops bool
    getter/setter pair

    Methods

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toString() String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited