AtCollectionModelFactoryManager class

Annotations
  • @Deprecated("Use AtClient.collection for collection-style operations")

Properties

collectionFactories ↔ List<AtCollectionModelFactory<AtCollectionModel>>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T extends AtCollectionModel>(String collectionName) → AtCollectionModelFactory<T>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(AtCollectionModelFactory<AtCollectionModel> factory) → void
toString() → String
A string representation of this object.
inherited
unregister(AtCollectionModelFactory<AtCollectionModel> factory) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited