AtJsonCollectionModelFactory class

Inheritance
Annotations
  • @Deprecated("Use AtClient.collection for collection-style operations")

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptCollection(String collectionName) bool
returns true if the factory creates instances of atCollectionModel for the given collectionName
override
create() AtCollectionModel
Expected to return an instance of T
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
priority() int
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited