AtKey class

Constructors

AtKey()

Properties

fullKey String
no setter
fullKeyAndOwner String
no setter
hashCode int
The hash code for this object.
no setteroverride
isLocal bool
When set to true, indicates that this key is a LocalKey. A LocalKey will remain in local storage on the client, and will never be synced to the cloud atServer.
getter/setter pair
isRef bool
getter/setter pair
key String
The 'identifier' part of an atProtocol key name. For example if the key is @bob:city.address.my_app@alice then the key would be city.address and the namespace would be my_app
getter/setter pair
metadata Metadata
getter/setter pair
namespace String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedBy String?
The 'owner' part of an atProtocol key name. For example if the key is @bob:city.address.my_app@alice then sharedBy is @alice
getter/setter pair
sharedWith String?
The 'recipient' part of an atProtocol key name. For example if the key is @bob:city.address.my_app@alice then sharedWith is @bob
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

assertStartsWithAtIfNotEmpty(String? atSign) → void
fromString(String key) AtKey
getKeyType(String key, {bool enforceNameSpace = false}) KeyType
Returns one of the valid keys from KeyType if there is a regex match. Otherwise returns KeyType.invalidKey Set enforceNamespace=true for strict namespace validation in the key.
local(String key, String sharedBy, {String? namespace}) → LocalKeyBuilder
Local key are confined to the client(device)/server it is created. The key does not sync between the local-secondary and the cloud-secondary.
private(String key, {String? namespace}) → PrivateKeyBuilder
Obsolete, was never used
public(String key, {String? namespace, String sharedBy = ''}) → PublicKeyBuilder
Public keys are visible to everyone and shown in an authenticated/unauthenticated scan
self(String key, {String? namespace, String sharedBy = ''}) → SelfKeyBuilder
Self keys that are created by the owner of the atSign and the keys can be accessed by the owner of the atSign only.
shared(String key, {String? namespace, String sharedBy = ''}) → SharedKeyBuilder
Shared Keys are shared with other atSign. The owner can see the keys on authenticated scan. The sharedWith atSign can lookup the value of the key.