AtRootDomain class

Constructors

AtRootDomain(String rootDomain, int rootPort)
const
AtRootDomain.parse(String value)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isProxyAddress bool
no setter
rootDomain String
final
rootPort int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

atsignDomain → const AtRootDomain