ChainResult class

Annotations
  • @experimental

Constructors

ChainResult(ChainVerdict verdict, List<String> path, String? reason)

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → List<String>
The enrollments walked, starting with the one asked about.
final
reason → String?
Why the walk stopped, when that is not self-evident.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verdict → ChainVerdict
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited