EnrollmentListRequestParam class

Class to store request parameters while fetching a list of enrollments

Properties

appName ↔ String?
getter/setter pair
deviceName ↔ String?
getter/setter pair
enrollmentListFilter ↔ List<EnrollmentStatus>
Allows filtering of enroll requests while listing them
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
namespace ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited