KeyMaker class abstract

Annotations
  • @Deprecated("Use AtClient.collection for collection-style operations")

Constructors

KeyMaker()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createSelfKey({required String keyId, required String collectionName, required String namespace, ObjectLifeCycleOptions? objectLifeCycleOptions}) → AtKey
createSharedKey({required String keyId, required String collectionName, required String namespace, String? sharedWith, ObjectLifeCycleOptions? objectLifeCycleOptions}) → AtKey
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited