RegexesNonMandatoryNamespace class

Implemented types

Properties

cachedPublicKey String
no setteroverride
cachedSharedKey String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
localKey String
no setteroverride
privateKey String
no setteroverride
publicKey String
no setteroverride
reservedKey String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfKey String
no setteroverride
sharedKey String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited