RemoteLocalPref enum

Default preference on how to handle get, put and delete requests with regards to use of local storage vs the remote atServer.

Inheritance
Available extensions

Values

localOnly → const RemoteLocalPref

The default - operate on local storage, and rely on the background sync processing to push changes to the remote atServer.

remoteOnly → const RemoteLocalPref

Operate on remote only - i.e. do not interact with local storage at all. Note that if the application is syncing, then the change will be pulled to local from remote as part of the sync process.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RemoteLocalPref>
A constant List of the values in this enum, in order of their declaration.