RemoteSecondary class

Contains methods used to execute verbs on remote secondary server of the atSign.

Constructors

RemoteSecondary(String atSign, AtClientPreference preference, {String? privateKey, AtChops? atChops, AtLookUp? atLookUp, String? enrollmentId})

Properties

atChops ↔ AtChops?
getter/setter pair
atLookUp ↔ AtLookUp
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
logger ↔ AtSignLogger
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addStreamData(List<int> data) → void
authenticateCram(String? secret) Future<bool>
Generates digest using from verb response and secret and performs a CRAM authentication to secondary server
closeConnection() Future<void>
executeAndParse(VerbBuilder builder, {dynamic sync = false}) Future<String>
executeCommand(String atCommand, {bool auth = false}) Future<String?>
executeVerb(VerbBuilder builder, {bool? sync = false, bool cameFromServer = false}) Future<String>
Executes the command returned by VerbBuilder on a remote secondary server. Authentication is handled by the injected AtLookUp. sync is accepted for Secondary interface compatibility but is ignored. cameFromServer is also accepted for interface compatibility and ignored — remote secondaries don't have a client→server sync queue to skip enqueuing into.
findSecondaryUrl() Future<String?>
isAvailable() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sync(int lastSyncedId, {String? regex}) Future<String?>
Executes sync verb on the remote server. Return commit entries greater than lastSyncedId.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited