publicKeyCacheSettings property
How to handle caching of public keys used for verification
Set this value to null to disable caching.
cacheExpiry: how long until the cached public key expires (used for verification)
resetOnLookup: Whether to reset the expiry timer when a lookup is made
Implementation
abstract final ({
Duration cacheExpiry,
bool resetOnLookup
})? publicKeyCacheSettings;