saveApkamKeys property
Supply to persist a freshly generated enc keypair (e.g. to the keyfile / platform keystore — the app's concern).
Implementation
Future<void> Function(PersistedApkamKeys keys)? saveApkamKeys;
Supply to persist a freshly generated enc keypair (e.g. to the keyfile / platform keystore — the app's concern).
Future<void> Function(PersistedApkamKeys keys)? saveApkamKeys;