ReceivedEnvelope class
A decrypted, signature-verified payload received from another APKAM keypair of the same atSign.
- Annotations
-
- @experimental
Constructors
Properties
- appNamespace → String
-
The application namespace the envelope was addressed through (and which
the atServer authorized the recipient's enrollment for).
final
- fromEnrollmentId → String
-
final
- fromKpid → String
-
The sender's key-package id (KeyPackage.kpid).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
payload
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited