appNamespace property
The application namespace the envelope was addressed through (and which the atServer authorized the recipient's enrollment for).
Implementation
final String appNamespace;
The application namespace the envelope was addressed through (and which the atServer authorized the recipient's enrollment for).
final String appNamespace;