ReceivedSecret class
A Secret another APKAM keypair of this atSign shared with this client.
- Annotations
-
- @experimental
Constructors
- ReceivedSecret({required Secret secret, required String fromKpid, required String fromEnrollmentId})
Properties
- fromEnrollmentId → String
-
final
- fromKpid → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secret → Secret
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited