fromKpid property
The sender's key-package id (KeyPackage.kpid) — so the recipient of a request can seal its reply straight back to this APKAM keypair.
Implementation
final String fromKpid;
The sender's key-package id (KeyPackage.kpid) — so the recipient of a request can seal its reply straight back to this APKAM keypair.
final String fromKpid;