SqliteSyncQueueStore class

A SyncQueueStore in a sync_queue table on the keystore's own database.

Constructors

SqliteSyncQueueStore(SqliteDatabase _db)

Properties

hashCode → int
The hash code for this object.
no setterinherited
keys → Iterable<String>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future<void>
close() → Future<void>
delete(String atKey) → Future<void>
get(String atKey) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String atKey, String record) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited