AtServiceFactory class abstract
Abstraction over the construction of the core services managed by AtClientManager.
The default production implementation is DefaultAtServiceFactory. Override this in tests to inject fakes or mocks without subclassing AtClientManager.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
atClient(
String atSign, String? namespace, AtClientPreference preference, AtClientManager atClientManager, {AtChops? atChops, AtLookUp? atLookUp, String? enrollmentId}) → Future< AtClient> -
enrollmentService(
AtClient atClient) → EnrollmentService -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notificationService(
AtClient atClient, AtClientManager atClientManager, {SecondaryAddressFinder? secondaryAddressFinder}) → Future< NotificationService> -
syncService(
AtClient atClient, AtClientManager atClientManager, NotificationService notificationService) → Future< SyncService> -
The
notificationServiceparameter is ignored — the sync service retrieves its notification dependency directly fromatClientafter construction. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited