RemoteSecondary class
Contains methods used to execute verbs on remote secondary server of the atSign.
Constructors
- RemoteSecondary(String atSign, AtClientPreference preference, {String? privateKey, AtChops? atChops, AtLookUp? atLookUp, String? enrollmentId})
Properties
Methods
-
addStreamData(
List< int> data) → void -
authenticateCram(
String? secret) → Future< bool> -
Generates digest using from verb response and
secretand performs a CRAM authentication to secondary server -
closeConnection(
) → Future< void> -
executeAndParse(
VerbBuilder builder, {dynamic sync = false}) → Future< String> -
executeCommand(
String atCommand, {bool auth = false}) → Future< String?> -
executeVerb(
VerbBuilder builder, {bool? sync = false, bool cameFromServer = false}) → Future< String> -
Executes the command returned by
VerbBuilderon a remote secondary server. Authentication is handled by the injectedAtLookUp.syncis accepted forSecondaryinterface compatibility but is ignored.cameFromServeris also accepted for interface compatibility and ignored — remote secondaries don't have a client→server sync queue to skip enqueuing into. -
findSecondaryUrl(
) → Future< String?> -
isAvailable(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sync(
int lastSyncedId, {String? regex}) → Future< String?> -
Executes sync verb on the remote server. Return commit entries greater than
lastSyncedId. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited