offersNewOperations static method
Whether status may be chosen for something new — a signer picking a
key to sign with, a sender picking a key to seal to.
Only active. Every other token, known or not, is a statement that the owner has withdrawn the key from new use.
Implementation
static bool offersNewOperations(KeyEntryStatus status) => status == active;